@@ -78,7 +78,9 @@ typedef enum {
 
 	/* these are not necessarily error */
 	BRASERO_BURN_WARNING_CHECKSUM,
-	BRASERO_BURN_WARNING_INSERT_AFTER_COPY
+	BRASERO_BURN_WARNING_INSERT_AFTER_COPY,
+
+	BRASERO_BURN_ERROR_TMP_DIRECTORY
 } BraseroBurnError;
 
 /**
